; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------
[Command]
name = Shien_Hiryuu_Kyaku1
command = ~D, DB, B, D, DB, B, a
time = 30

[Command]
name = Shien_Hiryuu_Kyaku2
command = ~D, DB, B, D, DB, B, b
time = 30

[Command]
name = Shien_Hiryuu_Kyaku3
command = ~D, DB, B, D, DB, B, c
time = 30

[Command]
name = Rekka_ShinKen1
command = ~D, DF, F, D, DF, F, x
time = 30

[Command]
name = Rekka_ShinKen2
command = ~D, DF, F, D, DF, F, y
time = 30

[Command]
name = Rekka_ShinKen3
command = ~D, DF, F, D, DF, F, z
time = 30

[Command]
name = Rekka_ShinKen3_SDM
command = ~D, DF, F, D, DF, F, x+y+z
time = 30
;-| Special Motions |------------------------------------------------------

; Rising_Dragon_A
[Command]
name = Shien_Kyaku_A
command = ~B, D, DB, a

; Rising_Dragon_B
[Command]
name = Shien_Kyaku_B
command = ~B, D, DB, b

; Rising_Dragon_C
[Command]
name = Shien_Kyaku_C
command = ~B, D, DB, c

; Light Rakkaken
[Command]
name = Rakka_X
command = ~D, DF, F, x

; Medium Rakkaken
[Command]
name = Rakka_Y
command = ~D, DF, F, y

; Hard Rakkaken
[Command]
name = Rakka_Z
command = ~D, DF, F, z
;-| Double Tap |-----------------------------------------------------------
[Command]
name = FF       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = BB       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = recovery ;Required (do not remove)
command = a+b
time = 1

[Command]
name = ab
command = a+b
time = 1

[Command]
name = by
command = b+y
time = 1

;--------------------------------
;Roll
;--------------------------------
[Command]
name = fwd_z
command = /F,z
time = 1

[Command]
name = back_z
command = /B,z
time = 1

[Command]
name = DB_z
command = /DB,z
time = 1
;--------------------------------
[Command]
name = fwd_b
command = /F,b
time = 1

[Command]
name = back_b
command = /B,b
time = 1

[Command]
name = fwd_c
command = /F,c
time = 1

[Command]
name = fwd_xy
command = /F,x+y
time = 1

[Command]
name = back_xy
command = /B,x+y
time = 1

[Command]
name = fwd_yz
command = /F,y+z
time = 1

[Command]
name = back_yz
command = /B,y+z
time = 1

[Command]
name = fwd_ab
command = /F, a+b
time = 1

[Command]
name = back_ab
command = /B, a+b
time = 1

[Command]
name = fwd_bc
command = /F, b+c
time = 1

[Command]
name = back_bc
command = /B, b+c
time = 1
;-| Single Button |---------------------------------------------------------
[Command]
name = a
command = a
time = 1

[Command]
name = b
command = b
time = 1

[Command]
name = c
command = c
time = 1

[Command]
name = x
command = x
time = 1

[Command]
name = y
command = y
time = 1

[Command]
name = z
command = z
time = 1

[Command]
name = hold_a
command = /$a
time = 1

[Command]
name = hold_x
command = /$x
time = 1

[Command]
name = hold_b
command = /$b
time = 1
;-| Hold Dir |--------------------------------------------------------------
[Command]
name = holdfwd  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = holdback ;Required (do not remove)
command = /$B
time = 1

[Command]
name = holdup   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = holddown ;Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
;===========================================================================
; Rekka_ShinKen (Level1)
[State -1]
type = ChangeState
value = 3103
triggerall = power = 3000
triggerall = Life <= 250
triggerall = command = Rekka_ShinKen3_SDM
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 220
trigger6 = movecontact = 1
trigger7 = stateno = 221
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 241
trigger11 = movecontact = 1
trigger12 = stateno = 250
trigger12 = movecontact = 1
trigger13 = stateno = 251
trigger13 = movecontact = 1
trigger14 = stateno = 400
trigger14 = movecontact = 1
trigger15 = stateno = 410
trigger15 = movecontact = 1
trigger16 = stateno = 420
trigger16 = movecontact = 1
trigger17 = stateno = 430
trigger17 = movecontact = 1
trigger18 = stateno = 440
trigger18 = movecontact = 1
trigger19 = stateno = 450
trigger19 = movecontact = 1
;---------------------------------------------------------------------------
; Rekka_ShinKen (Level1)
[State -1]
type = ChangeState
value = 3100
triggerall = power >= 1000
triggerall = command = Rekka_ShinKen1
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 220
trigger6 = movecontact = 1
trigger7 = stateno = 221
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 241
trigger11 = movecontact = 1
trigger12 = stateno = 250
trigger12 = movecontact = 1
trigger13 = stateno = 251
trigger13 = movecontact = 1
trigger14 = stateno = 400
trigger14 = movecontact = 1
trigger15 = stateno = 410
trigger15 = movecontact = 1
trigger16 = stateno = 420
trigger16 = movecontact = 1
trigger17 = stateno = 430
trigger17 = movecontact = 1
trigger18 = stateno = 440
trigger18 = movecontact = 1
trigger19 = stateno = 450
trigger19 = movecontact = 1
;---------------------------------------------------------------------------
; Rekka_ShinKen (Level2)
[State -1]
type = ChangeState
value = 3101
triggerall = power >= 2000
triggerall = command = Rekka_ShinKen2
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 220
trigger6 = movecontact = 1
trigger7 = stateno = 221
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 241
trigger11 = movecontact = 1
trigger12 = stateno = 250
trigger12 = movecontact = 1
trigger13 = stateno = 251
trigger13 = movecontact = 1
trigger14 = stateno = 400
trigger14 = movecontact = 1
trigger15 = stateno = 410
trigger15 = movecontact = 1
trigger16 = stateno = 420
trigger16 = movecontact = 1
trigger17 = stateno = 430
trigger17 = movecontact = 1
trigger18 = stateno = 440
trigger18 = movecontact = 1
trigger19 = stateno = 450
trigger19 = movecontact = 1
;---------------------------------------------------------------------------
; Rekka_ShinKen (Level3)
[State -1]
type = ChangeState
value = 3102
triggerall = power = 3000
triggerall = command = Rekka_ShinKen3
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 220
trigger6 = movecontact = 1
trigger7 = stateno = 221
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 241
trigger11 = movecontact = 1
trigger12 = stateno = 250
trigger12 = movecontact = 1
trigger13 = stateno = 251
trigger13 = movecontact = 1
trigger14 = stateno = 400
trigger14 = movecontact = 1
trigger15 = stateno = 410
trigger15 = movecontact = 1
trigger16 = stateno = 420
trigger16 = movecontact = 1
trigger17 = stateno = 430
trigger17 = movecontact = 1
trigger18 = stateno = 440
trigger18 = movecontact = 1
trigger19 = stateno = 450
trigger19 = movecontact = 1
;---------------------------------------------------------------------------
; Shien_Hiryuu_Kyaku (Level1)
[State -1]
type = ChangeState
value = 3000
triggerall = power >= 1000
triggerall = command = Shien_Hiryuu_Kyaku1
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 220
trigger6 = movecontact = 1
trigger7 = stateno = 221
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 241
trigger11 = movecontact = 1
trigger12 = stateno = 250
trigger12 = movecontact = 1
trigger13 = stateno = 251
trigger13 = movecontact = 1
trigger14 = stateno = 400
trigger14 = movecontact = 1
trigger15 = stateno = 410
trigger15 = movecontact = 1
trigger16 = stateno = 420
trigger16 = movecontact = 1
trigger17 = stateno = 430
trigger17 = movecontact = 1
trigger18 = stateno = 440
trigger18 = movecontact = 1
trigger19 = stateno = 450
trigger19 = movecontact = 1
;---------------------------------------------------------------------------
; Shien_Hiryuu_Kyaku (Level 2)
[State -1]
type = ChangeState
value = 3004
triggerall = power >= 2000
triggerall = command = Shien_Hiryuu_Kyaku2
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 220
trigger6 = movecontact = 1
trigger7 = stateno = 221
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 241
trigger11 = movecontact = 1
trigger12 = stateno = 250
trigger12 = movecontact = 1
trigger13 = stateno = 251
trigger13 = movecontact = 1
trigger14 = stateno = 400
trigger14 = movecontact = 1
trigger15 = stateno = 410
trigger15 = movecontact = 1
trigger16 = stateno = 420
trigger16 = movecontact = 1
trigger17 = stateno = 430
trigger17 = movecontact = 1
trigger18 = stateno = 440
trigger18 = movecontact = 1
trigger19 = stateno = 450
trigger19 = movecontact = 1
;---------------------------------------------------------------------------
; Shien_Hiryuu_Kyaku (Level 3)
[State -1]
type = ChangeState
value = 3006
triggerall = power = 3000
triggerall = command = Shien_Hiryuu_Kyaku3
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 220
trigger6 = movecontact = 1
trigger7 = stateno = 221
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 241
trigger11 = movecontact = 1
trigger12 = stateno = 250
trigger12 = movecontact = 1
trigger13 = stateno = 251
trigger13 = movecontact = 1
trigger14 = stateno = 400
trigger14 = movecontact = 1
trigger15 = stateno = 410
trigger15 = movecontact = 1
trigger16 = stateno = 420
trigger16 = movecontact = 1
trigger17 = stateno = 430
trigger17 = movecontact = 1
trigger18 = stateno = 440
trigger18 = movecontact = 1
trigger19 = stateno = 450
trigger19 = movecontact = 1
;---------------------------------------------------------------------------
;Shien_Kyaku A
[State -1]
type = ChangeState
value = 1000
triggerall = command = Shien_Kyaku_A         
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 220
trigger6 = movecontact = 1
trigger7 = stateno = 221
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 241
trigger11 = movecontact = 1
trigger12 = stateno = 250
trigger12 = movecontact = 1
trigger13 = stateno = 251
trigger13 = movecontact = 1
trigger14 = stateno = 400
trigger14 = movecontact = 1
trigger15 = stateno = 410
trigger15 = movecontact = 1
trigger16 = stateno = 420
trigger16 = movecontact = 1
trigger17 = stateno = 430
trigger17 = movecontact = 1
trigger18 = stateno = 440
trigger18 = movecontact = 1
trigger19 = stateno = 450
trigger19 = movecontact = 1
;---------------------------------------------------------------------------
;Shien_Kyaku B
[State -1]
type = ChangeState
value = 1002
triggerall = command = Shien_Kyaku_B         
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 220
trigger6 = movecontact = 1
trigger7 = stateno = 221
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 241
trigger11 = movecontact = 1
trigger12 = stateno = 250
trigger12 = movecontact = 1
trigger13 = stateno = 251
trigger13 = movecontact = 1
trigger14 = stateno = 400
trigger14 = movecontact = 1
trigger15 = stateno = 410
trigger15 = movecontact = 1
trigger16 = stateno = 420
trigger16 = movecontact = 1
trigger17 = stateno = 430
trigger17 = movecontact = 1
trigger18 = stateno = 440
trigger18 = movecontact = 1
trigger19 = stateno = 450
trigger19 = movecontact = 1
;---------------------------------------------------------------------------
;Shien_Kyaku C
[State -1]
type = ChangeState
value = 1004
triggerall = command = Shien_Kyaku_C         
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 220
trigger6 = movecontact = 1
trigger7 = stateno = 221
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 241
trigger11 = movecontact = 1
trigger12 = stateno = 250
trigger12 = movecontact = 1
trigger13 = stateno = 251
trigger13 = movecontact = 1
trigger14 = stateno = 400
trigger14 = movecontact = 1
trigger15 = stateno = 410
trigger15 = movecontact = 1
trigger16 = stateno = 420
trigger16 = movecontact = 1
trigger17 = stateno = 430
trigger17 = movecontact = 1
trigger18 = stateno = 440
trigger18 = movecontact = 1
trigger19 = stateno = 450
trigger19 = movecontact = 1
;---------------------------------------------------------------------------
;Light Rakkaken (Part 1)
[State -1]
type = ChangeState
value = 1100
triggerall = command = Rakka_X         
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 220
trigger6 = movecontact = 1
trigger7 = stateno = 221
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 241
trigger11 = movecontact = 1
trigger12 = stateno = 250
trigger12 = movecontact = 1
trigger13 = stateno = 251
trigger13 = movecontact = 1
trigger14 = stateno = 400
trigger14 = movecontact = 1
trigger15 = stateno = 410
trigger15 = movecontact = 1
trigger16 = stateno = 420
trigger16 = movecontact = 1
trigger17 = stateno = 430
trigger17 = movecontact = 1
trigger18 = stateno = 440
trigger18 = movecontact = 1
trigger19 = stateno = 450
trigger19 = movecontact = 1

;---------------------------------------------------------------------------
;Light Rekka ken (Part 2)
[State -1]
type = ChangeState
value = 1101
triggerall = command = Rakka_X
triggerall = stateno = 1100
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1100

;Light Rekka ken (Part 2)
[State -1]
type = ChangeState
value = 1101
triggerall = command = Rakka_Y
triggerall = stateno = 1100
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1100

;Light Rekka ken (Part 2)
[State -1]
type = ChangeState
value = 1101
triggerall = command = Rakka_Z
triggerall = stateno = 1100
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1100

;******************

;Light Rekka ken (Part 3)
[State -1]
type = ChangeState
value = 1102
triggerall = command = Rakka_X
triggerall = stateno = 1101
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1101

;Light Rekka ken (Part 3)
[State -1]
type = ChangeState
value = 1102
triggerall = command = Rakka_Y
triggerall = stateno = 1101
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1101

;Light Rekka ken (Part 3)
[State -1]
type = ChangeState
value = 1102
triggerall = command = Rakka_Z
triggerall = stateno = 1101
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1101
;---------------------------------------------------------------------------
;Medium Rekka ken (Part 1)
[State -1]
type = ChangeState
value = 1103
triggerall = command = Rakka_Y         
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 220
trigger6 = movecontact = 1
trigger7 = stateno = 221
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 241
trigger11 = movecontact = 1
trigger12 = stateno = 250
trigger12 = movecontact = 1
trigger13 = stateno = 251
trigger13 = movecontact = 1
trigger14 = stateno = 400
trigger14 = movecontact = 1
trigger15 = stateno = 410
trigger15 = movecontact = 1
trigger16 = stateno = 420
trigger16 = movecontact = 1
trigger17 = stateno = 430
trigger17 = movecontact = 1
trigger18 = stateno = 440
trigger18 = movecontact = 1
trigger19 = stateno = 450
trigger19 = movecontact = 1
;---------------------------------------------------------------------------
;Medium Rekka ken (Part 2)
[State -1]
type = ChangeState
value = 1104
triggerall = command = Rakka_X
triggerall = stateno = 1103
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1103

;Medium Rekka ken (Part 2)
[State -1]
type = ChangeState
value = 1104
triggerall = command = Rakka_Y
triggerall = stateno = 1103
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1103

;Medium Rekka ken (Part 2)
[State -1]
type = ChangeState
value = 1104
triggerall = command = Rakka_Z
triggerall = stateno = 1103
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1103

;******************

;Medium Rekka ken (Part 3)
[State -1]
type = ChangeState
value = 1105
triggerall = command = Rakka_X
triggerall = stateno = 1104
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1104

;Medium Rekka ken (Part 3)
[State -1]
type = ChangeState
value = 1105
triggerall = command = Rakka_Y
triggerall = stateno = 1104
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1104

;Medium Rekka ken (Part 3)
[State -1]
type = ChangeState
value = 1105
triggerall = command = Rakka_Z
triggerall = stateno = 1104
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1104
;---------------------------------------------------------------------------
;Hard Rekka ken (Part 1)
[State -1]
type = ChangeState
value = 1106
triggerall = command = Rakka_Z         
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 220
trigger6 = movecontact = 1
trigger7 = stateno = 221
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 241
trigger11 = movecontact = 1
trigger12 = stateno = 250
trigger12 = movecontact = 1
trigger13 = stateno = 251
trigger13 = movecontact = 1
trigger14 = stateno = 400
trigger14 = movecontact = 1
trigger15 = stateno = 410
trigger15 = movecontact = 1
trigger16 = stateno = 420
trigger16 = movecontact = 1
trigger17 = stateno = 430
trigger17 = movecontact = 1
trigger18 = stateno = 440
trigger18 = movecontact = 1
trigger19 = stateno = 450
trigger19 = movecontact = 1
;---------------------------------------------------------------------------
;Hard Rekka ken (Part 2)
[State -1]
type = ChangeState
value = 1107
triggerall = command = Rakka_X
triggerall = stateno = 1106
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1106

;Hard Rekka ken (Part 2)
[State -1]
type = ChangeState
value = 1107
triggerall = command = Rakka_Y
triggerall = stateno = 1106
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1106

;Hard Rekka ken (Part 2)
[State -1]
type = ChangeState
value = 1107
triggerall = command = Rakka_Z
triggerall = stateno = 1106
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1106
;******************

;Hard Rekka ken (Part 3)
[State -1]
type = ChangeState
value = 1108
triggerall = command = Rakka_X
triggerall = stateno = 1107
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1107

;Hard Rekka ken (Part 3)
[State -1]
type = ChangeState
value = 1108
triggerall = command = Rakka_Y
triggerall = stateno = 1107
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1107

;Hard Rekka ken (Part 3)
[State -1]
type = ChangeState
value = 1108
triggerall = command = Rakka_Z
triggerall = stateno = 1107
trigger1 = time >= 12
trigger2 = movecontact = 1
trigger2 = time >= 8
trigger2 = stateno = 1107

;RunFwd
;[State -1]
;type = ChangeState
;value = 100
;trigger1 = command = FF
;trigger1 = statetype = S
;trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = BB
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
Stand_Throw (close dir+y)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = ChangeState
value = 2550
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = fwd_xy   ;p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = fwd_ab   ;p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
;---------------------------------------------------------------------------
;Stand_Throw (close dir+b)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = ChangeState
value = 2500
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = fwd_yz   ;p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = fwd_yz   ;p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
;---------------------------------------------------------------------------
;Air_Throw1 (close dir+b)
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = fwd_b
trigger2 = command = back_b

;---------------------------------------------------------------------------
;Light Punch
[State -1]
type = ChangeState
value = 200
triggerall = command = x         
triggerall = command != holddown
triggerall = P2bodydist X > 30
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1

;Light Punch
[State -1]
type = ChangeState
value = 201
triggerall = command = x         
triggerall = command != holddown
triggerall = P2bodydist X < 30
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 201
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
;---------------------------------------------------------------------------
; Medium Punch
[State -1]
type = ChangeState
value = 210
triggerall = command = y      
triggerall = command != holddown  
triggerall = P2bodydist X > 30
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 201
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 230
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 231
trigger6 = movecontact = 1

; Medium Punch Close
[State -1]
type = ChangeState
value = 211
triggerall = command = y      
triggerall = command != holddown  
triggerall = P2bodydist X < 30
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 201
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 230
trigger4 = movecontact = 1
trigger5 = stateno = 231
trigger5 = movecontact = 1
;---------------------------------------------------------------------------
; Hard Punch
[State -1]
type = ChangeState
value = 220
triggerall = command = z      
triggerall = command != holddown 
triggerall = P2bodydist X > 20 
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 211
trigger3 = movecontact = 1
trigger4 = stateno = 240
trigger4 = movecontact = 1
trigger5 = stateno = 221
trigger5 = movecontact = 1

; Hard Punch Close
[State -1]
type = ChangeState
value = 221
triggerall = command = z      
triggerall = command != holddown 
triggerall = P2bodydist X < 20 
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
; Light Kick
[State -1]
type = ChangeState
value = 230
triggerall = command = a
triggerall = P2bodydist X > 30
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 231
trigger5 = movecontact = 1

; Light Kick Close
[State -1]
type = ChangeState
value = 231
triggerall = command = a
triggerall = P2bodydist X < 30
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
; Medium Kick F
[State -1]
type = ChangeState
value = 242
triggerall = command = fwd_b
trigger1 = statetype = S
trigger1 = ctrl = 1

; Medium Kick B
[State -1]
type = ChangeState
value = 242
triggerall = command = back_b
trigger1 = statetype = S
trigger1 = ctrl = 1

; Medium Kick
[State -1]
type = ChangeState
value = 240
triggerall = command = b
triggerall = P2bodydist X > 30
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 201
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 231
trigger6 = movecontact = 1

; Medium Kick Close
[State -1]
type = ChangeState
value = 241
triggerall = command = b
triggerall = P2bodydist X < 30
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 201
trigger4 = movecontact = 1
trigger5 = stateno = 211
trigger5 = movecontact = 1
trigger6 = stateno = 231
trigger6 = movecontact = 1
;---------------------------------------------------------------------------
; Hard Kick
[State -1]
type = ChangeState
value = 252
triggerall = command = fwd_c
trigger1 = statetype = S
trigger1 = ctrl = 1

; Hard Kick
[State -1]
type = ChangeState
value = 250
triggerall = command = c
triggerall = P2bodydist X > 30
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 240
trigger2 = movecontact = 1
trigger3 = stateno = 211
trigger3 = movecontact = 1
trigger4 = stateno = 251
trigger4 = movecontact = 1
trigger5 = stateno = 241
trigger5 = movecontact = 1

; Hard Kick Close
[State -1]
type = ChangeState
value = 251
triggerall = command = c
triggerall = P2bodydist X < 30
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 240
trigger2 = movecontact = 1
trigger3 = stateno = 211
trigger3 = movecontact = 1
trigger4 = stateno = 241
trigger4 = movecontact = 1
;---------------------------------------------------------------------------
;Crouch Light Punch
[State -1]
type = ChangeState
value = 400
triggerall = command = x
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 201
trigger4 = movecontact = 1
trigger5 = stateno = 230
trigger5 = movecontact = 1
trigger6 = stateno = 231
trigger6 = movecontact = 1
trigger7 = stateno = 430
trigger7 = movecontact = 1
;---------------------------------------------------------------------------
;Crouch Medium Punch
[State -1]
type = ChangeState
value = 410
triggerall = command = y
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400
trigger2 = movecontact = 1
trigger3 = stateno = 231
trigger3 = movecontact = 1
trigger4 = stateno = 430
trigger4 = movecontact = 1
trigger5 = stateno = 440
trigger5 = movecontact = 1
trigger6 = stateno = 200
trigger6 = movecontact = 1
trigger7 = stateno = 201
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 211
trigger9 = movecontact = 1
trigger10 = stateno = 230
trigger10 = movecontact = 1
;---------------------------------------------------------------------------
;Crouch Hard Punch
[State -1]
type = ChangeState
value = 420
triggerall = command = z
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 211
trigger3 = movecontact = 1
trigger4 = stateno = 240
trigger4 = movecontact = 1
trigger5 = stateno = 241
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1
;---------------------------------------------------------------------------
;Crouch Light Kick
[State -1]
type = ChangeState
value = 430
triggerall = command = a
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 230
trigger4 = movecontact = 1
trigger5 = stateno = 231
trigger5 = movecontact = 1
trigger6 = stateno = 400
trigger6 = movecontact = 1
trigger7 = stateno = 430
trigger7 = movecontact = 1
;---------------------------------------------------------------------------
;Crouch Medium Kick
[State -1]
type = ChangeState
value = 440
triggerall = command = b
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 430
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 230
trigger4 = movecontact = 1
trigger5 = stateno = 231
trigger5 = movecontact = 1
trigger6 = stateno = 400
trigger6 = movecontact = 1
trigger7 = stateno = 200
trigger7 = movecontact = 1
trigger8 = stateno = 410
trigger8 = movecontact = 1
trigger9 = stateno = 211
trigger9 = movecontact = 1
trigger10 = stateno = 210
trigger10 = movecontact = 1
;---------------------------------------------------------------------------
;Crouch Hard Kick
[State -1]
type = ChangeState
value = 450
triggerall = command = c
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 440
trigger2 = movecontact = 1
trigger3 = stateno = 211
trigger3 = movecontact = 1
trigger4 = stateno = 240
trigger4 = movecontact = 1
trigger5 = stateno = 241
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 210
trigger7 = movecontact = 1
;---------------------------------------------------------------------------
; JUMP NEUTRAL Light Kick
[State -1]
type = ChangeState
value = 631
triggerall = vel X = 0
trigger1 = command = a
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Jump Light Kick
[State -1]
type = ChangeState
value = 630
trigger1 = command = a
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
; JUMP NEUTRAL MEDIUM Kick
[State -1]
type = ChangeState
value = 641
triggerall = vel X = 0
trigger1 = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Jump Medium Kick
[State -1]
type = ChangeState
value = 640
trigger1 = statetype = A
trigger1 = command = b
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
; Jump Neutral Light Punch
[State -1]
type = ChangeState
value = 600
triggerall = vel X = 0
trigger1 = statetype = A
trigger1 = command = x
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
; Jump Light Punch
[State -1]
type = ChangeState
value = 601
trigger1 = statetype = A
trigger1 = command = x
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
; JUMP NEUTRAL MEDIUM PUNCH
[State -1]
type = ChangeState
value = 610
triggerall = vel X = 0
trigger1 = command = y
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
; JUMP MEDIUM PUNCH
[State -1]
type = ChangeState
value = 611
trigger1 = command = y
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
; JUMP NEUTRAL Hard PUNCH
[State -1]
type = ChangeState
value = 621
triggerall = vel X = 0
trigger1 = command = z
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
; JUMP HARD PUNCH
[State -1]
type = ChangeState
value = 620
trigger1 = command = z
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
; JUMP NEUTRAL Hard Kick
[State -1]
type = ChangeState
value = 651
triggerall = vel X = 0
trigger1 = command = c
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Jump Hard Kick
[State -1]
type = ChangeState
value = 650
trigger1 = command = c
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------